Structs
- IamClient
- Client forPharia Identity Access Management. Authenticate and authorize users.
- User
Info AndPermissions - Returned by
IamClient::check_user. Contains information describing the user as well as the union of the queried permissions and the privileges of the user.
Enums
- Authorization
Error - Check
User Error - An error returned by
IamClient::check_user. Note that this does not include unauthorized. To check for authorization inspect the permissions ofUserInfoAndPermissions - Permission
Constants
- IAM_
PRODUCTION_ URL - URL of IAM in our production environment
- IAM_
STAGE_ URL