UserInfoAndPermissions

Struct UserInfoAndPermissions 

pub struct UserInfoAndPermissions {
    pub sub: String,
    pub email: Option<String>,
    pub email_verified: Option<bool>,
    pub permissions: Vec<Permission<'static>>,
}
Returned by IamClient::check_user. Contains information describing the user as well as the union of the queried permissions and the privileges of the user.

Fields

sub: String

Unique ID of the User

email: Option<String>

Email of the user. None for Service users

email_verified: Option<bool>

May be None for Service Users

permissions: Vec<Permission<'static>>

List of requested permissions, which are privieleges of the User Service. They are in the same order as in the query