Crate pharia_common

Crate pharia_common 

Structs

IamClient
Client forPharia Identity Access Management. Authenticate and authorize users.
UserInfoAndPermissions
Returned by IamClient::check_user. Contains information describing the user as well as the union of the queried permissions and the privileges of the user.

Enums

CheckUserError
An error returned by IamClient::check_user. Note that this does not include unauthorized. To check for authorization inspect the permissions of UserInfoAndPermissions
Permission

Constants

IAM_PRODUCTION_URL
URL of IAM in our production environment