IamClient

Struct IamClient 

pub struct IamClient { /* private fields */ }
Client forPharia Identity Access Management. Authenticate and authorize users.

Implementations

Source

impl IamClient

pub fn new(base_url: String) -> Self

Construct a new client using the respective IAM instance. E.g. IAM_PRODUCTION_URL

pub async fn check_user<'a>( &self, token: impl Display, permissions: &'a [Permission<'a>], ) -> Result<UserInfoAndPermissions, CheckUserError>

One stop shop for both authentication and authorization.

Parameters
  • token: Service or user token used for authentication.
  • permissions: A list of all permissions you are interested in. The response will contain the subset of these permissions which are privileges the user has.

Example Authorize Assistant Access against production instance

pub use pharia_common::{IamClient, Permission, IAM_PRODUCTION_URL, CheckUserError};

pub async fn is_authorized(token: &str) -> Result<bool, CheckUserError> {
    let iam = IamClient::new(IAM_PRODUCTION_URL.to_owned());
    let permissions = [Permission::AssistantAccess];
    let user_info = iam.check_user(token, &permissions).await?;
    let is_authorized = user_info.permissions == permissions;
    Ok(is_authorized)
}